==> urban_airship_web_push_notifications-7.x-1.0.tar.gz: urban_airship_web_push_notifications/includes/SnippetHtml.php <==
<?php

/**
 * Build Snippet HTML based on SDK Bundle files.
 */
class SnippetHtml {

  /**
   * Generate JS snippet to include on pages.
   */
  public function getSnippet() {
    // Remove <script> tags from the source file.
    // We're rebuilding <script> tag in .module file.
    $javascript = str_replace(['<script type="text/javascript">', '</script>'], '', variable_get('urban_airship_web_push_notifications_snippet.html'));
    if (!empty(variable_get('urban_airship_web_push_notifications_secure-bridge.html'))) {
      $javascript = $this->addSecureIframeUrl($javascript);
    }
    return $javascript;
  }

  /**
   * Adding `secureIframeUrl` parameter to the snippet file to support
   * secure bridge.
   * See https://docs.urbanairship.com/platform/web/#secure-domain-bridge-http-scenarios-only
   */
  protected function addSecureIframeUrl($javascript) {
    global $base_url;
    $snippet = [];
    // Secure bridge only works when HTTPS enabled.
    // Make sure https://examples.com/web-push-secure-bridge.html path is using HTTPS.
    $secure_bridge_url = url('/web-push-secure-bridge.html');
    $components = parse_url($base_url);
    $port = (!empty($components['port']) && $components['port'] != 80) ? ':' . $components['port'] : '';
    $domain = variable_get('urban_airship_web_push_notifications_sb_domain', 'https://' . $components['host'] . $port);
    foreach (preg_split("/((\r?\n)|(\r\n?))/", $javascript) as $line) {
      if (strstr($line, 'appKey:')) {
        $snippet[] = $line;
        $snippet[] = "\tsecureIframeUrl: '" . $domain . $secure_bridge_url . "',";
      }
      else {
        $snippet[] = $line;
      }
    }
    return join("\n", $snippet);
  }

}

==> urban_airship_web_push_notifications-7.x-1.1.tar.gz: urban_airship_web_push_notifications/includes/SnippetHtml.php <==
<?php

/**
 * Build Snippet HTML based on SDK Bundle files.
 */
class SnippetHtml {

  /**
   * Generate JS snippet to include on pages.
   */
  public function getSnippet() {
    // Remove <script> tags from the source file.
    // We're rebuilding <script> tag in .module file.
    $javascript = str_replace(array('<script type="text/javascript">', '</script>'), '', variable_get('urban_airship_web_push_notifications_snippet.html'));
    if (!empty(variable_get('urban_airship_web_push_notifications_secure-bridge.html'))) {
      $javascript = $this->addSecureIframeUrl($javascript);
    }
    return $javascript;
  }

  /**
   * Adding `secureIframeUrl` parameter to the snippet file to support
   * secure bridge.
   * See https://docs.urbanairship.com/platform/web/#secure-domain-bridge-http-scenarios-only
   */
  protected function addSecureIframeUrl($javascript) {
    global $base_url;
    $snippet = array();
    // Secure bridge only works when HTTPS enabled.
    // Make sure https://examples.com/web-push-secure-bridge.html path is using HTTPS.
    $secure_bridge_url = url('/web-push-secure-bridge.html');
    $components = parse_url($base_url);
    $port = (!empty($components['port']) && $components['port'] != 80) ? ':' . $components['port'] : '';
    $domain = variable_get('urban_airship_web_push_notifications_sb_domain', 'https://' . $components['host'] . $port);
    foreach (preg_split("/((\r?\n)|(\r\n?))/", $javascript) as $line) {
      if (strstr($line, 'appKey:')) {
        $snippet[] = $line;
        $snippet[] = "\tsecureIframeUrl: '" . $domain . $secure_bridge_url . "',";
      }
      else {
        $snippet[] = $line;
      }
    }
    return join("\n", $snippet);
  }

}
